@@ -67,43 +67,58 @@ VALOR_UPGRADES: typing.List[int] = [
     272,
 ]
 DUNGEON = [DUNGEON_NORMAL] + [DUNGEON_HEROIC] + [DUNGEON_MYTHIC] + DUNGEON_MYTHIC_LEVELS
-TAZAVESH = [226, 233]
-WORLD_BOSS_CHAINS_OF_DEVASTATION = 233
-WORLD_BOSS_ZERETH_MORTIS = 259
-
-# raids
-CASTLE_NATHRIA = [187, 200, 213, 226]
-CASTLE_NATHRIA_ENDBOSSES = list([ilvl + 7 for ilvl in CASTLE_NATHRIA])
-
-SANCTUM_OF_DOMINATION = [213, 226, 239, 252]
-SANCTUM_OF_DOMINATION_ENDBOSSES = list([ilvl + 7 for ilvl in SANCTUM_OF_DOMINATION])
-
-SEPULCHER_OF_THE_FIRST_ONES = [239, 252, 265, 278]
-SEPULCHER_OF_THE_FIRST_ONES_ENDBOSSES = list(
-    [ilvl + 7 for ilvl in SEPULCHER_OF_THE_FIRST_ONES]
-)
-
-UPPER_BOUND = SANCTUM_OF_DOMINATION_ENDBOSSES[-1]
-
-PVP_HONOR = [
-    239,
-    242,
-    246,
-    249,
-    252,
-    255,
-    259,
-]
-PVP_CONQUEST = [
-    249,
-    252,
-    255,
-    259,
+SEASON_4_DUNGEON = [
     262,
     265,
     268,
     272,
     275,
+    278,  # + weekly
+    281,  # + weekly
+    285,  # + weekly
+    288,  # + weekly
+    291,  # weekly
+    294,  # weekly
+    298,  # weekly
+    301,  # weekly
+    304,  # weekly
+]
+TAZAVESH = [226, 233]
+WORLD_BOSS_CHAINS_OF_DEVASTATION = 233
+WORLD_BOSS_ZERETH_MORTIS = 259
+
+# raids
+SEASON_4_RAID = [265, 278, 291, 304]
+SEASON_4_RAID_ENDBOSSES = [272, 285, 297, 311]
+
+CASTLE_NATHRIA = SEASON_4_RAID
+CASTLE_NATHRIA_ENDBOSSES = SEASON_4_RAID_ENDBOSSES
+
+SANCTUM_OF_DOMINATION = SEASON_4_RAID
+SANCTUM_OF_DOMINATION_ENDBOSSES = SEASON_4_RAID_ENDBOSSES
+
+SEPULCHER_OF_THE_FIRST_ONES = SEASON_4_RAID
+SEPULCHER_OF_THE_FIRST_ONES_ENDBOSSES = SEASON_4_RAID_ENDBOSSES
+
+PVP_HONOR = [
+    229,
+    236,
+    242,
+    249,
+    255,
+    262,
+    268,
+]
+PVP_CONQUEST = [
+    275,
+    278,
+    281,
+    285,
+    288,
+    291,
+    294,
+    298,
+    301,
 ]
 PVP = PVP_HONOR + PVP_CONQUEST
 
